@@ -107,7 +107,8 @@ void View::addApplet(const QString &applet)
     }
 
     if (!a->pluginInfo().isValid()) {
-        qCritical() << i18n("Applet %1 doesn't exist!").arg(applet);
+        // xgettext:no-c-format
+        qCritical() << i18n("Applet %1 doesn't exist!", applet);
         return;
     }
     m_lastAppletName = applet;
@@ -123,7 +124,8 @@ void View::addContainment(const QString &cont)
     Plasma::Containment *c = corona()->createContainment(actualCont);
 
     if (!c->pluginInfo().isValid()) {
-        qCritical() << i18n("Containment %1 doesn't exist").arg(actualCont);
+        // xgettext:no-c-format
+        qCritical() << i18n("Containment %1 doesn't exist", actualCont);
         return;
     }
 
@@ -269,7 +271,7 @@ ViewerCorona *View::createCorona()
 
 void View::takeScreenShot()
 {
-    QDBusInterface interface(QStringLiteral("org.kde.kwin"), QStringLiteral("/Screenshot"),
+    QDBusInterface interface(QStringLiteral("org.kde.KWin"), QStringLiteral("/Screenshot"),
                              QStringLiteral("org.kde.kwin.Screenshot"));
 
     QDBusPendingCall async = interface.asyncCall(QStringLiteral("screenshotArea"), x(), y(),
